@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import numpy as np
 import pandas as pd
 from tqdm import tqdm
 from termcolor import colored
@@ -38,14 +39,14 @@ class Player:
     ###########################################################################
     # Player info
     ###########################################################################
-    def __init__(self, name, bPaths, id=None, timezone=None):
+    def __init__(self, name, bPaths, id=None, timezone=None, replaceNAN=True):
         self.name = name
         self.id = id
         self.bPaths = bPaths
         self.timezone = timezone
         # Parse player's battles dataframes -----------------------------------
         self.battleRecords = self.getBattleRecords()
-        self.battlesHistory = self.parsePlayerHistoryFromBattles()
+        self.battlesHistory = self.parsePlayerHistoryFromBattles(replaceNAN=replaceNAN)
         self.battlesHistoryByType = self.getPlayerHistoryByTypes()
         # Assign stats --------------------------------------------------------
         self.playerStats = self.calcPlayerStats()
@@ -75,7 +76,9 @@ class Player:
     ###########################################################################
     # Get player history dataframe
     ###########################################################################
-    def parsePlayerHistoryFromBattles(self, validOnly=True):
+    def parsePlayerHistoryFromBattles(
+            self, validOnly=True, ammendWeapons=True, replaceNAN=True
+        ):
         """Extracts the player's history from the battle records by matching the name in the dataframes.
 
         Args:
@@ -90,7 +93,15 @@ class Player:
         )
         battlesHistory['winBool'] = [1 if i=='W' else 0 for i in battlesHistory['win']]
         battlesHistory['loseBool'] = [1 if i=='L' else 0 for i in battlesHistory['win']]
-        self.battlesHistory = battlesHistory
+        battlesHistory['participation'] = [1]*battlesHistory.shape[0]
+        battlesHistory['kassist'] = (battlesHistory['kill']+0.5*battlesHistory['assist'])
+        battlesHistory['kad'] = battlesHistory['kassist']/ [max(i, 1) for i in battlesHistory['death']]
+        if replaceNAN:
+            battlesHistory.replace([np.inf, np.nan, -np.inf], 0, inplace=True)
+        if ammendWeapons:
+            self.battlesHistory = battlesHistory.replace('Hero Shot Replica', 'Splattershot')
+        else:
+            self.battlesHistory = battlesHistory
         return self.battlesHistory
     
     def getPlayerHistoryByTypes(self):
