@@ -168,6 +168,11 @@ GEAR_GRUB_FUN_S3            = ('#8A19F7', '#BE7118', '#28C05E', '#3F2CD2')
 GRASS_FIRE_WATER_S3         = ('#1BA974', '#DA4514', '#002AFF', '#FFFF00')
 SPICY_SWEET_SOUR_S3         = ('#AD5438', '#9A6FCC', '#A5B533', '#00A2E8')
 DARK_MILK_WHITE_S3          = ('#3D1F7A', '#995935', '#D6BF8F', '#FFFF00')
+NESSIE_ALIENS_BIGFOOT_S3    = ('#118F32', '#793199', '#A1482B', '#0935A6')
+POWER_WISDOM_COURAGE_S3     = ('#AB2A5C', '#488DB5', '#03A65F', '#ba8500')
+VANILLA_STRAWBERRY_MINT_S3  = ('#cca770', '#bc6d75', '#2ac29e', '#adff6b')
+MONEY_FAME_LOVE             = ('#c8752d', '#73bd49', '#bb497b', '#5998ff')
+SHIVER_FRYE_BIGMAN_S3       = ('#253fc5', '#d3b113', '#d80501', '#6dda25')
 # Return of the Mammalians ----------------------------------------------------
 ORANGE_V_BLUE_S3            = ('#EE8711', '#0943F0', '#81DE17')
 YELLOW_V_INDIGO_S3          = ('#DEC109', '#531BBA', '#C920B7')
@@ -206,6 +211,21 @@ for name in all_variables:
 ALL_COLORS = list(set(ALL_COLORS))
 shuffle(ALL_COLORS)
 
+###############################################################################
+# Custom Season Colors
+###############################################################################
+SEASON_COLORS = (
+  ('#D01D79', '#1D07AC'), ('#6BFF00', '#1D07AC'),
+  ('#E1772B', '#1D07AC'), ('#A714D4', '#1D07AC'),
+  ('#6BFF00', '#D01D79'), ('#AEF4F0', '#D01D79'),
+  ('#6B87BF', '#D01D79'), ('#E1772B', '#D01D79'),
+  ('#D01D79', '#1D07AC'), ('#6BFF00', '#1D07AC'),
+  ('#E1772B', '#1D07AC'), ('#A714D4', '#1D07AC'),
+  ('#6BFF00', '#D01D79'), ('#AEF4F0', '#D01D79'),
+  ('#6B87BF', '#D01D79'), ('#E1772B', '#D01D79'),
+  ('#D01D79', '#1D07AC')
+)
+
 ###############################################################################
 # Auxiliary Functions
 ###############################################################################
