@@ -74,17 +74,21 @@ CLR_FEST = {
     False: clr.LMODEL_V_PMODEL_S2[-1]
 }
 CLR_STAGE = {
+    'Barnacle & Dime': clr.GHERKOUT_V_GHERKIN_S2[1],
     'Brinewater Springs': clr.GRAPE_V_TURQUOISE_S2[0], 
+    'Crableg Capital': clr.SHIVER_FRYE_BIGMAN_S3[-1],
     'Eeltail Alley': clr.PINK_V_ORANGE_S1[1],
     'Flounder Heights': clr.SWEATER_V_SOCKS_S2[0],
     'Hagglefish Market': clr.LPINK_V_BLUE_S2[1],
     'Hammerhead Bridge': clr.MAYO_V_KETCHUP_S2[1],
+    'Humpback Pump Track': clr.CALLIE_V_MARIE_S1[1],
     'Inkblot Art Academy': clr.LPINK_V_BLUE_S2[0],
     'Mahi-Mahi Resort': clr.CHAOS_V_ORDER_S2[1],
     'MakoMart': clr.PINK_V_GREEN_S1[2],
     'Mincemeat Metalworks': clr.TSUBUAN_V_KOSHIAN_S2[1],
     "Museum d'Alfonsino": clr.SALTY_V_SWEET_S2[0],
     'Scorch Gorge': clr.UNICORN_V_NARWHAL_S2[0],
+    'Shipshape Cargo Co.': clr.MONEY_FAME_LOVE[2],
     'Sturgeon Shipyard': clr.VAMPIRE_V_WEREWOLF_S2[2],
     'Undertow Spillway': clr.RASPBERRY_V_NYELLOW_S2[1],
     'Wahoo World': clr.PINK_V_ORANGE_S1[2],
@@ -98,16 +102,20 @@ CLR_WEAPON = {
     'Tentatek Splattershot': '#C920B7',
 }
 CLR_CLS_LONG = [
-    clr.LPINK_V_BLUE_S2[0], clr.LPINK_V_BLUE_S2[1],
-    clr.NPINK_V_NGREEN_S2[1], 
-    clr.RASPBERRY_V_NYELLOW_S2[1],
-    clr.WINNERW_V_WOUTERW_S2[0], clr.WINNERW_V_WOUTERW_S2[1], clr.WINNERW_V_WOUTERW_S2[2],
-    clr.YELLOW_V_LBLU_V_DBLU_LK_S3[1], clr.BLUE_FRYE_S3[2],
-    clr.GRAPE_V_TURQUOISE_S2[0], clr.GRAPE_V_TURQUOISE_S2[1],
     clr.TSUBUAN_V_KOSHIAN_S2[1],
     clr.FAM_V_FRIEND_S2[1],
     clr.DBLUE_V_YELLOW_S1[0],
-    clr.YELLOW_V_DTEAL_LK_S3[0], clr.YELLOW_V_DTEAL_LK_S3[1], clr.YELLOW_V_DTEAL_LK_S3[2]
+    clr.YELLOW_V_DTEAL_LK_S3[0], clr.YELLOW_V_DTEAL_LK_S3[1], clr.YELLOW_V_DTEAL_LK_S3[2],
+    clr.WINNERW_V_WOUTERW_S2[0], clr.WINNERW_V_WOUTERW_S2[1], clr.WINNERW_V_WOUTERW_S2[2],
+    clr.LPINK_V_BLUE_S2[0], clr.LPINK_V_BLUE_S2[1],
+    clr.NPINK_V_NGREEN_S2[1], 
+    clr.RASPBERRY_V_NYELLOW_S2[1],
+    clr.YELLOW_V_LBLU_V_DBLU_LK_S3[1], clr.BLUE_FRYE_S3[2],
+    clr.GRAPE_V_TURQUOISE_S2[0], clr.GRAPE_V_TURQUOISE_S2[1],
+    clr.PBODY_V_PBRAIN_S1[0], clr.PBODY_V_PBRAIN_S1[1],
+    clr.SGREEN_V_GRAPE_S2[0], clr.SGREEN_V_GRAPE_S2[1], clr.SGREEN_V_GRAPE_S2[2],
+    clr.TEAL_PURPLE_ORANGE_S3[0], clr.TEAL_PURPLE_ORANGE_S3[1], clr.TEAL_PURPLE_ORANGE_S3[2], clr.TEAL_PURPLE_ORANGE_S3[3],
+    clr.YELLOW_V_LBLU_V_DBLU_LK_S3[0], clr.YELLOW_V_LBLU_V_DBLU_LK_S3[1], clr.YELLOW_V_LBLU_V_DBLU_LK_S3[2], clr.YELLOW_V_LBLU_V_DBLU_LK_S3[3]
 ]
 CLR_BAR = clr.SMUSHROOM_V_SSTAR_S2[-1]
 ###############################################################################
