@@ -244,4 +244,15 @@ def boolToInt(entry, naValue=-1):
     if type(entry) is not bool:
         return naValue
     else:
-        return int(entry)
\ No newline at end of file
+        return int(entry)
+    
+
+def addDateGroup(
+        playerHistory, 
+        slicer=(lambda x: "{}/{:02d}".format(
+            x.isocalendar().year, x.isocalendar().week
+        ))
+    ):
+    dteSlice = playerHistory['datetime'].apply(slicer).copy()
+    playerHistory.insert(3, 'DateGroup', dteSlice)
+    return playerHistory
\ No newline at end of file
