@@ -1,11 +1,15 @@
 
 
+import math
 import squarify
+import pandas as pd
 import numpy as np
 import seaborn as sns
 from pywaffle import Waffle
+from matplotlib.colors import LogNorm
 import matplotlib.pyplot as plt
 from math import radians, log10
+import matplotlib.colors as mcolors
 from matplotlib.patches import Rectangle
 import SplatStats.constants as cst
 import SplatStats.stats as stats
@@ -810,7 +814,7 @@ def plotWaffleStat(
     """    
     (fig, ax) = figAx
     # Aggregate ---------------------------------------------------------------
-    df = playerHistory.groupby(grouping).agg(function)
+    df = playerHistory[[grouping, stat]].groupby(grouping).agg(function)
     cols = [
         i+aux.alphaToHex(alpha) for i in colors[:len(df.index)]
     ]
@@ -873,7 +877,7 @@ def plotCircularBarchartStat(
         (fix, ax): Matplotlib's fig and ax objects.
     """
     # Gather data -------------------------------------------------------------
-    df = playerHistory.groupby(cat).agg(aggFun)
+    df = playerHistory[[cat, stat]].groupby(cat).agg(aggFun)
     df.sort_values(by=[stat], inplace=True)
     catVals = list(df[stat])
     # Generate chart ----------------------------------------------------------
@@ -1047,3 +1051,350 @@ def polarBarRanks(
     # ax.set(frame_on=False)
     # Return ------------------------------------------------------------------
     return (fig, (ax_k, ax_d, ax_a, ax_p))
+
+
+
+
+
+def plotIrisKDP(
+        playerHistory, figAx, 
+        kassist=True, paint=True, 
+        clockwise=True, innerOffset=2,
+        colorsKD=('#4E4EDDCC', '#CD2D7ECC'), colorP='#6A1EC111',
+        rangeKD=(0, 40), rangeP=(0, 3500),
+        lw=0.25
+    ):
+    (fig, ax) = figAx
+    # Calculate numbers -------------------------------------------------------
+    (outer, inner) = (
+        np.array(playerHistory['kill']), 
+        np.array(playerHistory['death'])
+    )
+    bar = (np.array(playerHistory['paint']) if paint else None)
+    if kassist:
+        outer = outer + (.5*np.array(playerHistory['assist']))
+    kdRatio = np.sum(outer)/np.sum(inner)
+    (topArray, bottomArray, barArray) = (outer, inner, bar)
+    # Calculate angles for marker lines ---------------------------------------
+    DLEN = topArray.shape[0]
+    (astart, aend) = ((2*np.pi, 0) if clockwise else (0, 2*np.pi))
+    ANGLES = np.linspace(astart, aend, DLEN, endpoint=False)
+    # Draw top-bottom (kill-death) --------------------------------------------
+    if bottomArray is None:
+        bottomArray = np.zeros(topArray.shape)
+    heights = topArray-bottomArray
+    colors = [colorsKD[0] if (h>=0) else colorsKD[1] for h in heights]
+    ax.vlines(
+        ANGLES, innerOffset+bottomArray, innerOffset+topArray, 
+        lw=lw, colors=colors
+    )
+    # Draw bar ----------------------------------------------------------------
+    if barArray is None:
+        barScaled = np.zeros(topArray.shape)
+    else:
+        barScaled = np.interp(barArray, rangeP, (rangeKD[0]*2, rangeKD[1]*2))
+    ax.vlines(
+        ANGLES, innerOffset, innerOffset+barScaled,  
+        lw=lw, colors=colorP
+    )
+    # Return figAx and stats --------------------------------------------------
+    return ((fig, ax), kdRatio)
+
+
+def plotIrisMatch(
+        playerHistory, figAx,
+        innerRadius=40, typeLineLength=10, lw=0.25,
+        colorsKO=('#311AA8', '#E70F21', '#ffffff'),
+        offsets=(2, 5, 7), clockwise=True,
+        mTypeColors = {
+            'Clam Blitz': '#D60E6E',
+            'Rainmaker': '#7D26B5',
+            'Splat Zones': '#3D59DE',
+            'Tower Control': '#8ACF47',
+            'Tricolor Turf War': '#88214D',
+            'Turf War': '#D1D1D1'
+        },
+        winColors={True: '#6BD52C', False: '#D1D1D1'}
+    ):
+    (fig, ax) = figAx
+    # Calculate angles for marker lines ---------------------------------------
+    DLEN = np.array(playerHistory['kill']).shape[0]
+    (astart, aend) = ((2*np.pi, 0) if clockwise else (0, 2*np.pi))
+    ANGLES = np.linspace(astart, aend, DLEN, endpoint=False)
+    # Match type --------------------------------------------------------------
+    (mTypeOff, mTypeHeight) = (innerRadius+offsets[0], typeLineLength)
+    (wBoolOff, wBoolHeight) = (
+        mTypeOff+mTypeHeight, 
+        mTypeOff+mTypeHeight+offsets[1]
+    )
+    (kBoolOff, kBoolHeight) = (
+        mTypeOff+mTypeHeight+offsets[1], 
+        mTypeOff+mTypeHeight+offsets[2]
+    )
+    ax.vlines(
+        ANGLES, mTypeOff, mTypeOff+mTypeHeight, 
+        colors=[mTypeColors[i] for i in playerHistory['match type']],
+        zorder=-5, lw=lw
+    )
+    # Win ---------------------------------------------------------------------
+    ax.vlines(
+        ANGLES, wBoolOff, wBoolHeight, 
+        colors=[winColors[i] for i in playerHistory['winBool']],
+        zorder=-5, lw=lw
+    )
+    # KO ----------------------------------------------------------------------
+    winKO = []
+    for wko in list(zip(playerHistory['winBool'], playerHistory['ko'])):
+        if wko[-1]:
+            if wko[0]:
+                winKO.append(colorsKO[0])
+            else:
+                winKO.append(colorsKO[1])
+        else:
+            winKO.append(colorsKO[2])
+    ax.vlines(
+        ANGLES, kBoolOff, kBoolHeight, 
+        lw=lw, colors=winKO, zorder=-5
+    )
+    ax.set_rscale('symlog')
+    return (fig, ax)
+
+
+def plotIrisStats(
+        playerHistory, figAx,
+        binSize=1, binMax=20, innerOffset=2, meanStat=True, barWidth=0.1,
+        pstats=('kill', 'death', 'assist', 'special', 'ink'),
+        colorBarEdge='#00000033', linewidthEdge=0.1,
+        colorMean='#00000099', linewidthMean=0.5,
+        INKSTATS_STYLE = {
+            'kill': {
+                'color': '#1A1AAEDD', 'range': (0, 15),
+                'scaler': lambda x: np.interp(x, [0, 0.125, 0.25], [0, .50, 1]),
+                'range': (0, 15)
+            },
+            'death': {
+                'color': '#CD2D7EDD', 'range': (0, 15),
+                'scaler': lambda x: np.interp(x, [0, 0.125, 0.25], [0, .50, 1]),
+                'range': (0, 15)
+            },
+            'assist': {
+                'color': '#801AB3DD', 'range': (0, 10),
+                'scaler': lambda x: np.interp(x, [0, 0.250, 0.65], [0, .50, 1]),
+                
+            },
+            'special': {
+                'color': '#1FAFE8DD', 'range': (0, 10),
+                'scaler': lambda x: np.interp(x, [0, 0.250, 0.65], [0, .50, 1]),
+            },
+            'ink': {
+                'color': '#35BA49DD', 'range': (0, 20),
+                'scaler': lambda x: np.interp(x, [0, 0.100, 0.20], [0, .50, 1]),
+            }
+        }
+    ):
+    (fig, ax) = figAx
+    playerHistory['ink'] = playerHistory['paint']/100
+    statsHists = {
+        i: stats.calcBinnedFrequencies(
+            np.array(playerHistory[i]), 0, binMax, 
+            binSize=binSize, normalized=True
+        )
+        for i in pstats
+    }
+    # Vspan for stats -------------------------------------------------------------
+    binsNum = statsHists['kill'].shape[0]
+    (dHeight, rWidth) = (barWidth, 2*math.pi/binsNum)
+    statsNames = list(pstats)
+    # Iterate through stats
+    for (ix, stat) in enumerate(statsNames):
+        # Iterate through bins
+        (clr, sca) = (
+            mcolors.ColorConverter().to_rgba(INKSTATS_STYLE[stat]['color']),
+            INKSTATS_STYLE[stat]['scaler']
+        )
+        bins = statsHists[stat]
+        for (jx, h) in enumerate(range(binsNum)):
+            alpha = sca(bins[jx])
+            ax.add_patch(
+                Rectangle(
+                    (-jx*rWidth, innerOffset-ix*dHeight), -rWidth, -dHeight,
+                    facecolor=(clr[0], clr[1], clr[2], alpha),
+                    edgecolor=colorBarEdge, lw=linewidthEdge
+                )
+            )
+            ax.bar(0, 1).remove()
+    # Quantiles ---------------------------------------------------------------
+    statQNT = {s: np.quantile(playerHistory[s], [0.25, 0.50, 0.75]) for s in pstats}
+    statMNS = {s: np.mean(playerHistory[s]) for s in pstats}
+    rSca = 0.15
+    for (ix, stat) in enumerate(statsNames):
+        if meanStat:
+            rPos = np.interp(statMNS[stat], [0, binMax], [2*np.pi, 0])
+            ax.vlines(
+                rPos, 
+                innerOffset-(ix)*dHeight-rSca*dHeight, 
+                innerOffset-(1+ix)*dHeight+rSca*dHeight,  
+                lw=linewidthMean, colors=colorMean
+            )
+        else:
+            rPos = [
+                np.interp(x, [0, binMax], [2*np.pi, 0])-rWidth/2
+                for x in statQNT[stat]
+            ]
+            ax.vlines(
+                rPos[1], 
+                innerOffset-(ix)*dHeight-rSca*dHeight, 
+                innerOffset-(1+ix)*dHeight+rSca*dHeight,  
+                lw=linewidthMean, colors=colorMean
+            )
+            ax.vlines(
+                [rPos[0], rPos[2]], 
+                innerOffset-(ix)*dHeight-rSca*dHeight, 
+                innerOffset-(1+ix)*dHeight+rSca*dHeight,  
+                lw=linewidthMean*0.25, colors=colorMean
+            )
+    return ((fig, ax), statQNT, statMNS)
+
+
+def plotIrisAxes(
+        figAx, innerOffset=2, statsNum=5, yRange=(0, 100), 
+        barWidth=0.1, frameColor="#00000000", rangeKD=(0, 40), lw=0.25, 
+        innerGuides=(0, 6, 1), innerGuidesColor="#00000088",
+        outerGuides=(0, 50, 10), outerGuidesColor="#00000088"
+    ):
+    (fig, ax) = figAx
+    ax.vlines(
+        [0], innerOffset-barWidth*statsNum, innerOffset+rangeKD[1], 
+        lw=lw, color='#000000CC',
+        zorder=10
+    )
+    circleAngles = np.linspace(0, 2*np.pi, 200)
+    for r in range(*innerGuides):
+        ax.plot(
+            circleAngles, np.repeat(r+innerOffset, 200), 
+            color=innerGuidesColor, lw=0.1,
+            zorder=10
+        )
+    ax.plot(
+        circleAngles, np.repeat(innerOffset-barWidth*5, 200), 
+        color='#000000FF', lw=lw, # ls='-.', 
+        zorder=10
+    )
+    ax.set_theta_offset(np.pi/2)
+    ax.set_xticks([])
+    ax.set_xticklabels([])
+    ax.set_yticklabels([])
+    yTicks = [0+innerOffset] + list(np.arange(
+        outerGuides[0]+innerOffset, outerGuides[1]+innerOffset, outerGuides[2]
+    ))
+    ax.set_yticks(yTicks)
+    ax.yaxis.grid(True, color=outerGuidesColor, ls='-', lw=0.2, zorder=10)
+    ax.spines["start"].set_color("none")
+    ax.spines["polar"].set_color(frameColor)
+    ax.set_ylim(yRange[0], yRange[1])
+    return (fig, ax)
+
+
+def plotIrisHistory(
+        playerHistory, figAx=None, 
+        kassist=True, paint=True, innerOffset=2, clockwise=True,
+        colorsKD=('#4E4EDDCC', '#CD2D7ECC'), colorP='#6A1EC111',
+        rangeKD=(0, 40), rangeP=(0, 3500),
+    ):
+    # Generate (fig, ax) if needed --------------------------------------------
+    if figAx is None:
+        (fig, ax) = plt.subplots(
+            figsize=(10, 10), subplot_kw={"projection": "polar"}
+        )
+    else:
+        (fig, ax) = figAx
+    # Plot kill/death/paint bars ----------------------------------------------
+    ((fig, ax), kdRatio) = plotIrisKDP(
+            playerHistory, figAx, 
+            kassist=kassist, paint=paint, 
+            clockwise=clockwise, innerOffset=innerOffset,
+            colorsKD=colorsKD, colorP=colorP,
+            rangeKD=rangeKD, rangeP=rangeP,
+            lw=0.25
+        )
+    # Return figAx ------------------------------------------------------------
+    return (fig, ax)
+
+
+def plotTimecard(
+        timecard, wpnSorting,
+        figAx=None, yearRange=None, weekRange=None, reversed=False,
+        origin='N', direction=1, rRange=(0, 90), 
+        offset=0, height=1, edgeWidth=1, fontSize=12,
+        highColors=['#DE0B64AA', '#311AA8AA', '#6BFF00AA', '#9030FF55', '#B62EA7AA'],
+        baseColor='#ffffff55', maxValue=None,
+        fmtStr='  {} ({:.2f})', statScaler=1,
+    ):
+    # Get auxiliary variables -------------------------------------------------
+    wpnsNumber = len(wpnSorting)
+    cmaps = [clr.colorPaletteFromHexList([baseColor, c]) for c in highColors]
+    if not maxValue:
+        maxMag = max(timecard.max())
+        norm = LogNorm(vmin=1, vmax=maxMag)
+    else:
+        norm = LogNorm(vmin=1, vmax=maxValue)
+    if (yearRange is None) or (weekRange is None):
+        (minDate, maxDate) = (
+            sorted(timecard.columns)[0], sorted(timecard.columns)[-1]
+        )
+        (minYear, minWeek) = (int(minDate[:4]), int(minDate[5:]))
+        (maxYear, maxWeek) = (int(maxDate[:4]), int(maxDate[5:]))
+    else:
+        (minYear, maxYear) = yearRange
+        (minWeek, maxWeek) = weekRange
+    # Plot --------------------------------------------------------------------
+    if not figAx:
+        (fig, ax) = plt.subplots(
+            figsize=(10, 10), subplot_kw={"projection": "polar"}
+        )
+    for wpix in range(wpnsNumber):
+        (wpnCurrent, wpnTotal) = (
+            wpnSorting.index[::-1][wpix], wpnSorting.values[::-1][wpix]
+        )
+        wpnLabel = fmtStr.format(wpnCurrent, wpnTotal/statScaler)
+        cmapCurrent = cmaps[wpix%len(cmaps)]
+        # Get weapon values and dates -----------------------------------------
+        rowValues = timecard.loc[wpnCurrent]
+        if not reversed:
+            (rowDates, rowMagnitudes) = (
+                list(rowValues.index)[::-1], list(rowValues.values)[::-1]
+            )
+        else:
+            (rowDates, rowMagnitudes) = (
+                list(rowValues.index), list(rowValues.values)
+            )
+        # Convert dates to x coordinates --------------------------------------
+        dateTuples = [[int(x) for x in d.split('/')] for d in rowDates]
+        weekNumber = [(y%minYear)*52+w-minWeek+1 for (y, w) in dateTuples]
+        # Convert values to colors --------------------------------------------
+        rDelta = radians(rRange[1])/len(weekNumber)
+        deltas = np.arange(0, radians(rRange[1])+rDelta, rDelta)
+        weekBars = [(i*rDelta, rDelta) for i in range(len(deltas)-1)]
+        clrsBlocks = [cmapCurrent(norm(value)) for value in rowMagnitudes]
+        ax.broken_barh(
+            weekBars, (offset+wpix*height, height), lw=edgeWidth,
+            facecolors=clrsBlocks, edgecolors=baseColor
+        )
+        ax.text(
+            0, offset+wpix*height+height/2, wpnLabel,
+            va='center', ha='left', fontsize=fontSize
+        )
+    # Axis tweaks -------------------------------------------------------------
+    ax.set_xticklabels([])
+    ax.set_yticklabels([])
+    ax.set_thetamin(0)
+    ax.set_thetamax(rRange[1])
+    ax.set_ylim(0, offset+wpnsNumber*height)
+    ax.set_theta_zero_location(origin)
+    ax.set_theta_direction(direction)
+    ax.spines['polar'].set_visible(False)
+    ax.axis("off")
+    ax.set_rlabel_position(0)
+    ax.xaxis.grid(False)
+    ax.yaxis.grid(False)
+    return (fig, ax)
\ No newline at end of file
