@@ -4,6 +4,7 @@
 import numpy as np
 import pandas as pd
 import scipy.stats as sts
+import SplatStats.parsers as par
 
 
 def calcBattleHistoryStats(bHist, kassistWeight=0.5):
@@ -33,16 +34,27 @@ def calcBattleHistoryStats(bHist, kassistWeight=0.5):
     # Win/lose stats (NA are loss) ----------------------------------------
     win  = [True if i=='W' else False for i in bHist['win']]
     wins = sum(win)
-    winR = wins/len(win)
+    winR = (wins/len(win) if len(win) > 0 else 0)
     loss = len(win)-wins
     # Ratios --------------------------------------------------------------
-    killRatio = kTot/dTot
-    kallRatio = kaTot/dTot
+    killRatio = (kTot/dTot if dTot > 0 else 0)
+    kallRatio = (kaTot/dTot if dTot > 0 else 0)
     (kpm, dpm, apm, spm, ppm) = [
-        np.mean(bHist[i]/matchDuration) for i in cats
+        np.mean(
+            np.divide(
+                bHist[i], matchDuration, 
+                out=np.zeros_like(bHist[i]), 
+                where=matchDuration!=0
+            )
+        ) 
+        for i in cats
     ]
     kallpm = np.mean(
-        (bHist['kill']+kassistWeight*bHist['assist'])/matchDuration
+        np.divide(
+            (bHist['kill']+kassistWeight*bHist['assist']), matchDuration, 
+            out=np.zeros_like((bHist['kill']+kassistWeight*bHist['assist'])), 
+            where=matchDuration!=0
+        )
     )
     # Stats dictionary ----------------------------------------------------
     pStats = {
@@ -100,13 +112,12 @@ def calcBinnedFrequencies(array, xMin, xMax, binSize=1, normalized=False):
     Returns:
         array: Frequencies of ocurrences in the defined ranges.
     """    
-    freqs = np.array([
-        frequencyInRange(array, i, i+binSize) for i in 
-        range(xMin, xMax, binSize)
-    ])
-    total = np.sum(freqs)
+    rans = np.arange(xMin, xMax+binSize, binSize)
+    sArray = sorted(np.copy(array))
+    sortedIxs = np.searchsorted(sArray, rans, side='left')
+    freqs = np.diff(sortedIxs)
     if normalized:
-        freqs = freqs/total
+        freqs = freqs/np.sum(freqs)
     return freqs
 
 
@@ -348,4 +359,30 @@ def longestRun(myList, elem='W'):
                 max_size = size
         else:
             size = 0
-    return max_size
\ No newline at end of file
+    return max_size
+
+
+def statSummaries(playerHistory, stat, summaryFuns=(np.sum, np.mean)):
+    return [fun(playerHistory[stat]) for fun in summaryFuns]
+
+
+def statPerMinute(playerHistory, stat, summaryFun=None):
+    statPM = (playerHistory[stat]/(playerHistory['duration']/60))
+    stpm = summaryFun(statPM) if summaryFun else statPM
+    return stpm
+
+
+def getTimecard(
+        playerHistory, 
+        slicer=(lambda x: "{}/{:02d}".format(
+            x.isocalendar().year, x.isocalendar().week
+        ))
+    ):
+    par.addDateGroup(playerHistory, slicer=slicer)
+    grpd = playerHistory.groupby(['main weapon', 'DateGroup']).sum('kill')
+    grpd['kad'] = grpd['kassist']/grpd['death']
+    grpd.replace([np.inf, np.nan, -np.inf], 0, inplace=True)
+    dfGroups = grpd.unstack().reset_index().set_index("main weapon")
+    statsCats = sorted(list(set([i[0] for i in list(dfGroups.columns)])))
+    tCardsDict = {cat: dfGroups[cat] for cat in statsCats}
+    return tCardsDict
\ No newline at end of file
